@@ -9,21 +9,21 @@ fn main() {
     println!(
         r"
 -------------------------------------------------------------
--- Ultnote - For VS Code Extension - Rustnote ------------
+-- Ultnote - For VS Code Extension - Ultnote ------------
 -------------------------------------------------------------
 Ultnote is running on {host}
 
-The default path for your notes is ~/rustnote
-Change the path in File > Preferences > Settings > 'rustnote'
+The default path for your notes is ~/ultnote
+Change the path in File > Preferences > Settings > 'ultnote'
 
 --------------------------------------------------------------
 -- Default Keybindings ---------------------------------------
 --------------------------------------------------------------
-alt+f: Search notes in VS Code, add rustnote path to workspace
+alt+f: Search notes in VS Code, add ultnote path to workspace
 alt+p: Preview notes as static website using mdBook
 alt+o: Open main.rs to see what code is being generated
 
-Change in File > Preferences > Keyboard Shortcuts > 'rustnote'
+Change in File > Preferences > Keyboard Shortcuts > 'ultnote'
 "
     );
     // The Program will remain in state while the server is running
